<?php
$ap_theme_name = 'thepalace';

// themes options
require_once( get_template_directory() . '/aurel-panel/aurel-panel-options.php' );

// widget areas init
require_once( get_template_directory() . '/inc/widget-areas-init.php' );
add_action( 'widgets_init', 'ap_widgets_area_init' );

// custom widgets
function ap_register_widgets() {
	require_once( get_template_directory() . '/aurel-panel/aurel-panel-widgets.php' );
	register_widget( 'AP_Social_Widget' );
	register_widget( 'AP_Category_Posts' );
	register_widget( 'AP_Gallery_Widget' );
}
add_action( 'widgets_init', 'ap_register_widgets' );

// shortcodes
require_once( get_template_directory() . '/inc/shortcodes.php' );

// menu registration
function register_ap_menu() {
	register_nav_menu('ap_header_menu', 'Main Menu');
}
add_action('init', 'register_ap_menu');

// theme activation
function ap_theme_activation() {
	$msg = '<div class="updated"><p>Thanks for using <i><b>The Place</b></i> theme! Do not forget to have a look at the documentation by clicking <a href="http://s3e2.com/theme-forest/the-place-wordpress-documentation/" target="_blank">here</a>.</p></div>';
    add_action( 'admin_notices', create_function( '', 'echo "' . addcslashes( $msg, '"' ) . '";' ) );
}
add_action('after_switch_theme', 'ap_theme_activation');

// theme setup
function ap_theme_setup() {
	add_theme_support( 'automatic-feed-links' );
		
	add_theme_support( 'post-thumbnails' ); 

	add_image_size( 'image-90x90', 90, 90, true );
	add_image_size( 'image-120x120', 120, 120, true );
	add_image_size( 'image-420x180', 420, 180, true );
	add_image_size( 'image-630x210', 630, 210, true );
	add_image_size( 'image-930x310', 930, 310, true );
	add_image_size( 'image-scale-with-grid', 930, 400, true );
	add_image_size( 'image-scale-with-grid-full-height', 930, 99999 );
	add_image_size( 'image-width-930', 930, 99999 );

	add_filter('image_size_names_choose', 'ap_image_sizes');
	function ap_image_sizes($sizes) {
		$addsizes = array(
			'image-scale-with-grid' => 'Scale with grid (small height)',
			'image-scale-with-grid-full-height' => 'Scale with grid (full height)'
		); 	
		$newsizes = array_merge($sizes, $addsizes);
		return $newsizes;
	}
}
add_action( 'after_setup_theme', 'ap_theme_setup' );

// aurel-hotel-init
if ( $ap_options['ap_activate_hotel']['val'] == 'yes' ) {
	require_once( get_template_directory() . '/aurel-hotel/aurel-hotel-init.php' );
}

// misc
if ( ! isset( $content_width ) ) {
	$content_width = 930;
}

// ap-translator
function ap_translator( $default_str, $text, $arg3 = null, $arg4 = null ) {
	global $ap_options;
	$translation_manager_val = $ap_options['ap_translation_manager']['val'];
	$langs_list = array();
	foreach( $translation_manager_val['langs'] as $array_lang ) {
		$lang_list[] = $array_lang['code'];
	}
	if ( in_array( get_locale(), $lang_list ) ) {
		foreach ( $translation_manager_val['strings'] as $translation_str ) {
			$clean_default_str = preg_replace( "/[^A-Za-z]/", '', html_entity_decode( $default_str ));
			$clean_trans_str = preg_replace( "/[^A-Za-z]/", '', html_entity_decode( $translation_str['value']['Default'] ) );
			if ( $clean_default_str == $clean_trans_str ) {
				$default_str = str_replace( $translation_str['value']['Default'], $translation_str['value'][get_locale()], $default_str );
				$default_str = str_replace( htmlentities( $translation_str['value']['Default'], ENT_QUOTES, 'UTF-8' ), $translation_str['value'][get_locale()], $default_str );
			}
		}
	}
	return $default_str;
}

function ap_translator_with_context( $translation, $text, $context, $domain ){
	return ap_translator( $translation, $text, $domain );
}

add_filter( 'gettext', 'ap_translator', 10, 4 );
add_filter( 'gettext_with_context', 'ap_translator', 10, 4 );

if ( is_admin() ) { // i.e. back-end

	// aurel-panel-init
	require_once( get_template_directory() . '/aurel-panel/aurel-panel-init.php' );

	// custom fields
	require_once( get_template_directory() . '/inc/custom-fields.php' );
	
	// misc
	function change_media_button_text( $translation, $text, $domain ){
		if ( $text == 'Insert into Post' ) {
			return 'Use this image';
		}
		return $translation;
	}
	add_filter( 'gettext', 'change_media_button_text', 10, 3 );

} else { // !is_admin() i.e. front-end
	
	// comments displaying functions
	require_once( get_template_directory() . '/inc/comments-displaying.php' );
	
	// custom css
	require_once( get_template_directory() . '/inc/custom-css.php' );
	add_action('wp_head','palace_custom_css');
	
	// enqueue js scripts
	require_once( get_template_directory() . '/inc/enqueue-js-scripts.php' );
	add_action( 'wp_enqueue_scripts', 'ap_enqueue_js_scripts' );

	function load_aq_resizer() {
		require_once( get_template_directory() . '/img-resizer/aq_resizer.php' );
	}
	add_action('wp_head', 'load_aq_resizer');

	load_theme_textdomain( 'thepalace', get_template_directory() . '/lang' );
	/* end theme support - image size - language */

	// misc
	if (function_exists('qtrans_convertURL')) {
		add_filter('home_url', 'qtrans_convertURL');
	}
}
?>